@@ -1,4 +1,8 @@
-DATABASE_ENGINE = 'sqlite3'
+DATABASES = {
+    'default': {
+        'ENGINE': 'django.db.backends.sqlite3',
+    }
+}
 
 INSTALLED_APPS = (
     'django.contrib.contenttypes',
